@@ -1340,6 +1340,21 @@ Load (int argc, char **argv, Coord x, Coord y)
   static gchar *current_element_dir = NULL;
   static gchar *current_layout_dir = NULL;
   static gchar *current_netlist_dir = NULL;
+  static gchar *default_dir = NULL;
+
+  if (!default_dir)
+    if(PCB->Filename && *PCB->Filename)
+    {
+      gchar* pos;
+      default_dir = strdup(PCB->Filename);
+      pos = strrchr(default_dir, PCB_DIR_SEPARATOR_C);
+      if (pos != NULL)  *pos = 0;
+	  else
+	  {
+		free(default_dir);
+	    default_dir = NULL;
+      }
+    }
 
   /* we've been given the file name */
   if (argc > 1)
@@ -1350,26 +1365,26 @@ Load (int argc, char **argv, Coord x, Coord y)
   if (strcasecmp (function, "Netlist") == 0)
     {
       name = ghid_dialog_file_select_open (_("Load netlist file"),
-					   &current_netlist_dir,
-					   Settings.FilePath);
+			   current_netlist_dir ? &current_netlist_dir : &default_dir,
+			   Settings.FilePath);
     }
   else if (strcasecmp (function, "ElementToBuffer") == 0)
     {
       name = ghid_dialog_file_select_open (_("Load element to buffer"),
-					   &current_element_dir,
-					   Settings.LibraryTree);
+			   current_element_dir ? &current_element_dir : &default_dir,
+			   Settings.LibraryTree);
     }
   else if (strcasecmp (function, "LayoutToBuffer") == 0)
     {
-      name = ghid_dialog_file_select_open (_("Load layout file to buffer"),
-					   &current_layout_dir,
+	  name = ghid_dialog_file_select_open (_("Load layout file to buffer"),
+			   current_layout_dir ? &current_layout_dir : &default_dir,
 					   Settings.FilePath);
     }
   else if (strcasecmp (function, "Layout") == 0)
     {
-      name = ghid_dialog_file_select_open (_("Load layout file"),
-					   &current_layout_dir,
-					   Settings.FilePath);
+	  name = ghid_dialog_file_select_open (_("Load layout file"),
+			   current_layout_dir ? &current_layout_dir : &default_dir,
+			   Settings.FilePath);
     }
 
   if (name)
